@@ -8,23 +8,26 @@
 # PREFIX, RC and DESTDIR environment variables can be set to choose
 # installation paths
 
-# $Id: install.sh,v 1.26 2004/10/24 18:46:17 jerome Exp $
+# $Id: install.sh,v 1.34 2005/08/24 21:29:44 jerome Exp $
 
 set -o errexit
 set -o nounset
 
-langs="fr de pl it ru es zh_TW nl ja eo fi hu"
-templates="default joi satyap marc petrus"
+langs="fr de pl it ru es zh_TW nl ja eo fi hu ca"
+templates="swigs joi satyap marc petrus mwolson martin"
 
 DESTDIR="${DESTDIR:-}" # prefix to append to the install dirs
-                       # this is used for the Mandrake package
+                       # this is used by the Mandrake and Debian packages
 PREFIX="${PREFIX:-/usr/local}"
+ETC="${ETC:-/etc}"
 RC="${RC:-/etc/bins}"
 GLOBAL_RC="$RC"
 
 DESTDIR=`echo "$DESTDIR"|sed 's%/$%%'`
 PREFIX=$DESTDIR/`echo "$PREFIX"|sed 's%^/%%'`
 PREFIX=`echo "$PREFIX"|sed 's%/$%%'`
+ETC=$DESTDIR/`echo "$ETC"|sed 's%^/%%'`
+ETC=`echo "$ETC"|sed 's%/$%%'`
 RC=$DESTDIR/`echo "$RC"|sed 's%^/%%'`
 RC=`echo "$RC"|sed 's%/$%%'`
 
@@ -49,9 +52,8 @@ RC     = $RC
 
 ***************************** WARNING ********************************
 Note that this may replace your old programs, configuration files and
-HTML templates ("default" "satyap" and "joi" style) by new ones, so
-you should backup them if you have modified something for
-personalization.
+HTML templates by new ones, so you should backup them if you have
+modified something for personalization.
 **********************************************************************
 
 Press Enter to go on or Crtl-C to stop now...
@@ -64,7 +66,8 @@ install_binaries()
   mkdir -p $BIN 2>/dev/null || true
   if [ -w $BIN ] ; then
     echo "Installing program files in $BIN"
-    cp bins bins_edit bins_cleanupgallery bins-edit-gui anti_bins $BIN
+    # bins_cleanupgallery anti_bins
+    cp bins bins_edit bins-edit-gui $BIN
     chmod a+rx $BIN/bins
     chmod a+rx $BIN/bins_edit
     chmod a+rx $BIN/bins_cleanupgallery
@@ -112,6 +115,9 @@ install_data()
 	mkdir $DATA/templates.$T
       fi
       cp templates.$T/*.html $DATA/templates.$T
+      if ls templates.$T/*.js >/dev/null 2>&1 ; then
+	cp templates.$T/*.js $DATA/templates.$T
+      fi
       if [ -d templates.$T/static ] ; then
 	cp -R templates.$T/static $DATA/templates.$T
       fi
@@ -178,9 +184,9 @@ if [ -w $MAN ] ; then
 fi
 
 # bash completion
-if [ -w /etc/bash_completion.d ] ; then
+if [ -w $ETC/bash_completion.d ] ; then
   echo "Installing bash completion system wide."
-  cp -f bash_completion /etc/bash_completion.d/bins
+  cp -f bash_completion $ETC/bash_completion.d/bins
 else
   mkdir ~/.bash_completion 2>/dev/null || true
   if [ -w ~/.bash_completion ] ; then
